//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[FuroChanceShantenArgs](index.md)/[chanceTile](chance-tile.md)

# chanceTile

[common]\
val [chanceTile](chance-tile.md): [Tile](../../mahjongutils.models/-tile/index.md)

#### Parameters

common

| | |
|---|---|
| chanceTile | 副露机会牌（能够吃、碰的牌） |
